@@ -20,7 +20,7 @@ class TorchDAGClient:
     """
         Used to get/update information about pipeline from torch catalog.
     """
-    def __init__(self, conn_id) -> None:
+    def __init__(self, conn_id=None) -> None:
         self.torchClient = TorchClient(**torch_credentials(conn_id))
         self.latest_pipeline_run = None
 
